@@ -1,4 +1,8 @@
 # -*- coding:utf-8 -*-
+from __future__ import absolute_import
+from __future__ import unicode_literals
+from future import standard_library
+standard_library.install_hooks()
 
 import sys
 if sys.version_info >= (2, 7):
@@ -6,14 +10,15 @@ if sys.version_info >= (2, 7):
 else:
     import unittest2 as unittest
 
+from datetime import datetime
 import threading
 import time
-from datetime import datetime
 
 from limpyd import model
 from limpyd import fields
 from limpyd.exceptions import *
-from base import LimpydBaseTest, TEST_CONNECTION_SETTINGS
+
+from .base import LimpydBaseTest, TEST_CONNECTION_SETTINGS
 
 
 class TestRedisModel(model.RedisModel):
@@ -104,7 +109,7 @@ class InitTest(LimpydBaseTest):
 
     def test_wrong_field_name_cannot_be_used(self):
         with self.assertRaises(ValueError):
-            bike = Bike(power="human")
+            Bike(power="human")
 
     def test_fields_should_be_ordered(self):
         self.assertEqual(Bike._fields, ['pk', 'name', 'wheels', 'passengers'])
@@ -168,10 +173,10 @@ class DatabaseTest(LimpydBaseTest):
                 class Bike(TestRedisModel):
                     name = fields.StringField()
 
-            class Bike(TestRedisModel):
+            class Bike2(TestRedisModel):
                 name = fields.StringField()
                 namespace = 'sub-tests'
-            self.assertNotEqual(MainBike._name, Bike._name)
+            self.assertNotEqual(MainBike._name, Bike2._name)
 
         sub_test()
 
@@ -216,7 +221,8 @@ class DatabaseTest(LimpydBaseTest):
             Test that the database contains all non-abstract models in the given
             list and that each model has the correct database.
             """
-            self.assertEqual(database._models, dict((m._name, m) for m in models if not m.abstract))
+            self.assertEqual(database._models, dict((m._name, m) for m in models
+                                                                       if not m.abstract))
             for m in models:
                 self.assertEqual(m.database, database)
 
@@ -362,7 +368,7 @@ class IndexationTest(LimpydBaseTest):
         self.assertTrue(Bike.exists(name="tricycle"))
 
     def test_unicode_string_is_indexable(self):
-        bike = Bike(name=u"vélo")
+        Bike(name=u"vélo")
         self.assertFalse(Bike.exists(name="velo"))
         self.assertTrue(Bike.exists(name=u"vélo"))
 
@@ -391,23 +397,23 @@ class GetTest(LimpydBaseTest):
         self.assertEqual(boat1._pk, boat2._pk)
 
     def test_should_raise_if_more_than_one_match(self):
-        boat1 = Boat(name="Pen Duick I")
-        boat2 = Boat(name="Pen Duick II")
+        Boat(name="Pen Duick I")
+        Boat(name="Pen Duick II")
         with self.assertRaises(ValueError):
-            boat3 = Boat.get(power="sail")
+            Boat.get(power="sail")
 
     def test_should_raise_if_no_one_match(self):
-        boat1 = Boat(name="Pen Duick I")
+        Boat(name="Pen Duick I")
         with self.assertRaises(DoesNotExist):
-            boat3 = Boat.get(name="Pen Duick II")
+            Boat.get(name="Pen Duick II")
 
     def test_should_not_accept_more_than_one_arg(self):
         with self.assertRaises(ValueError):
-            boat = Boat.get(1, 2)
+            Boat.get(1, 2)
 
     def test_should_not_accept_no_params(self):
         with self.assertRaises(ValueError):
-            boat = Boat.get()
+            Boat.get()
 
 
 class GetOrConnectTest(LimpydBaseTest):
@@ -434,7 +440,7 @@ class UniquenessTest(LimpydBaseTest):
         self.assertEqual(boat1.length.get(), "15.1")
         # Try to create a boat with the same name
         with self.assertRaises(UniquenessError):
-            boat2 = Boat(name="Pen Duick I", length=15.1)
+            Boat(name="Pen Duick I", length=15.1)
         # Check data after
         self.assertEqual(boat1.name.get(), "Pen Duick I")
         self.assertEqual(boat1.length.get(), "15.1")
@@ -542,7 +548,8 @@ class InheritanceTest(LimpydBaseTest):
         self.assertEqual(set(bike._fields), set(['pk', 'name', 'wheels', 'passengers']))
         motorbike = MotorBike()
         self.assertEqual(len(motorbike._fields), 5)
-        self.assertEqual(set(motorbike._fields), set(['pk', 'name', 'wheels', 'passengers', 'power']))
+        self.assertEqual(set(motorbike._fields),
+                         set(['pk', 'name', 'wheels', 'passengers', 'power']))
         boat = Boat()
         self.assertEqual(len(boat._fields), 5)
         self.assertEqual(set(boat._fields), set(['pk', 'name', 'launched', 'power', 'length']))
@@ -561,8 +568,8 @@ class InheritanceTest(LimpydBaseTest):
         """
         Test that each model has its own collections
         """
-        bike = Bike(name="rosalie", wheels=4)
-        motorbike = MotorBike(name='davidson', wheels=2, power='not enough')
+        Bike(name="rosalie", wheels=4)
+        MotorBike(name='davidson', wheels=2, power='not enough')
         self.assertEqual(len(Bike.collection(name="rosalie")), 1)
         self.assertEqual(len(Bike.collection(name="davidson")), 0)
         self.assertEqual(len(MotorBike.collection(name="rosalie")), 0)
@@ -580,7 +587,7 @@ class DeleteTest(LimpydBaseTest):
             wagons = fields.StringField(default=10)
 
         # Check that db is empty
-        self.assertEqual(len(self.connection.keys()), 0)
+        self.assertEqual(self.count_keys(), 0)
         # Create two models, to check also that the other is not
         # impacted by the delete of some field
         train1 = Train(name="Occitan", kind="Corail")
@@ -594,20 +601,20 @@ class DeleteTest(LimpydBaseTest):
         # - the 2 kind fields
         # - the kind index for "Corail"
         # - the 2 wagons fields
-        self.assertEqual(len(self.connection.keys()), 11)
+        self.assertEqual(self.count_keys(), 11)
         # If we delete the name field, only 9 key must remain
         # the train1.name field and the name:"Occitan" index are deleted
         train1.name.delete()
-        self.assertEqual(len(self.connection.keys()), 9)
+        self.assertEqual(self.count_keys(), 9)
         self.assertEqual(train1.name.get(), None)
         self.assertFalse(Train.exists(name="Occitan"))
         self.assertEqual(train1.wagons.get(), '10')
         self.assertEqual(train2.name.get(), 'Teoz')
-        self.assertEqual(len(self.connection.keys()), 9)
+        self.assertEqual(self.count_keys(), 9)
         # Now if we delete the train1.kind, only one key is deleted
         # The kind:"Corail" is still used by train2
         train1.kind.delete()
-        self.assertEqual(len(self.connection.keys()), 8)
+        self.assertEqual(self.count_keys(), 8)
         self.assertEqual(len(Train.collection(kind="Corail")), 1)
 
     def test_instancehashfield_keys_are_deleted(self):
@@ -619,7 +626,7 @@ class DeleteTest(LimpydBaseTest):
             wagons = fields.InstanceHashField(default=10)
 
         # Check that db is empty
-        self.assertEqual(len(self.connection.keys()), 0)
+        self.assertEqual(self.count_keys(), 0)
         # Create two models, to check also that the other is not
         # impacted by the delete of some field
         train1 = Train(name="Occitan", kind="Corail")
@@ -631,24 +638,24 @@ class DeleteTest(LimpydBaseTest):
         # - 2 trains hash key
         # - the 2 names index (one by value)
         # - the kind index
-        self.assertEqual(len(self.connection.keys()), 7)
+        self.assertEqual(self.count_keys(), 7)
         # The train1 hash must have three fields (name, kind and wagons)
         self.assertEqual(self.connection.hlen(train1.key), 3)
         # If we delete the train1 name, only 6 key must remain
         # (the name index for "Occitan" must be deleted)
         train1.name.delete()
-        self.assertEqual(len(self.connection.keys()), 6)
+        self.assertEqual(self.count_keys(), 6)
         self.assertEqual(self.connection.hlen(train1.key), 2)
         self.assertEqual(train1.name.hget(), None)
         self.assertFalse(Train.exists(name="Occitan"))
         self.assertEqual(train1.wagons.hget(), '10')
         self.assertEqual(train2.name.hget(), 'Teoz')
-        self.assertEqual(len(self.connection.keys()), 6)
+        self.assertEqual(self.count_keys(), 6)
         # Now if we delete the train1.kind, no key is deleted
         # Only the hash field must be deleted
         # The kind:"Corail" is still used by train2
         train1.kind.delete()
-        self.assertEqual(len(self.connection.keys()), 6)
+        self.assertEqual(self.count_keys(), 6)
         self.assertEqual(self.connection.hlen(train1.key), 1)
         self.assertEqual(len(Train.collection(kind="Corail")), 1)
 
@@ -671,7 +678,7 @@ class DeleteTest(LimpydBaseTest):
             wagons = fields.InstanceHashField(default=10)
 
         # Check that db is empty
-        self.assertEqual(len(self.connection.keys()), 0)
+        self.assertEqual(self.count_keys(), 0)
         # Create two models, to check also that the other is not
         # impacted by the delete of some field
         train1 = Train(name="Occitan", kind="Corail")
@@ -684,10 +691,10 @@ class DeleteTest(LimpydBaseTest):
         # - the 2 names index (one by value)
         # - the two kind keys
         # - the kind:Corail index
-        self.assertEqual(len(self.connection.keys()), 9)
+        self.assertEqual(self.count_keys(), 9)
         # If we delete the train1, only 6 key must remain
         train1.delete()
-        self.assertEqual(len(self.connection.keys()), 6)
+        self.assertEqual(self.count_keys(), 6)
         with self.assertRaises(DoesNotExist):
             train1.name.hget()
         with self.assertRaises(DoesNotExist):
@@ -695,7 +702,7 @@ class DeleteTest(LimpydBaseTest):
         self.assertFalse(Train.exists(name="Occitan"))
         self.assertTrue(Train.exists(name="Teoz"))
         self.assertEqual(train2.name.hget(), 'Teoz')
-        self.assertEqual(len(self.connection.keys()), 6)
+        self.assertEqual(self.count_keys(), 6)
         self.assertEqual(len(Train.collection(kind="Corail")), 1)
         self.assertEqual(len(Train.collection()), 1)
 
